module HROOT.Graf.TAttImage
       (TAttImage(..), ITAttImage, upcastTAttImage, downcastTAttImage)
       where
import HROOT.Graf.TAttImage.RawType
import HROOT.Graf.TAttImage.Interface
import HROOT.Graf.TAttImage.Implementation
